@@ -20,30 +20,11 @@ import logging
 from importlib import import_module
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 
 log = logging.getLogger(__name__)
 
 
-def init_xframe_protection(app):
-    """
-    Add X-Frame-Options header.
-
-    Use it to avoid click-jacking attacks, by ensuring that their content is not embedded into other sites.
-
-    See also: https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options
-    """
-    x_frame_enabled = conf.getboolean("webserver", "X_FRAME_ENABLED", fallback=True)
-    if x_frame_enabled:
-        return
-
-    def apply_caching(response):
-        response.headers["X-Frame-Options"] = "DENY"
-        return response
-
-    app.after_request(apply_caching)
-
-
 def init_api_auth(app):
     """Load authentication backends."""
     auth_backends = conf.get(
